PyXMake Developer Guide: Class Members - Variables

| PyXMake Developer Guide 1.0 PyXMake

### - a -

- architecture : PyXMake.Build.Make.Make

### - b -

- buildid : PyXMake.Build.Make.Make
- buildname : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Custom , PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.SSH
- BuildOption : PyXMake.Build.Make.Sphinx

### - c -

- compargs : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Custom , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.Make
- copyfiles : PyXMake.Build.Make.Make

### - d -

- Data : PyXMake.Tools.Utility.GetDataFromPickle

### - e -

- environment : PyXMake.Build.Make.SSH
- exe : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Custom , PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.NSIS , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.Sphinx
- export : PyXMake.Build.Make.SSH
- Expression : PyXMake.Tools.ErrorHandling.InputError

### - f -

- Following : PyXMake.Tools.ErrorHandling.TransitionError
- ftp_client : PyXMake.Build.Make.NSIS

### - i -

- incdirs : PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Make , PyXMake.Build.Make.Sphinx
- incremental : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.SSH
- iniCompiler : PyXMake.Build.Make.Make
- intelpath : PyXMake.Build.Make.Make
- intermediate_wrapper : PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH
- isStatic : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran

### - l -

- libdirs : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.Make , PyXMake.Build.Make.SSH
- libname : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH
- libs : PyXMake.Build.Make.Make
- linkcmd : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH
- linkedIn : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH

### - m -

- makecmd : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Custom , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.Make , PyXMake.Build.Make.SSH
- MakeObjectKind : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Custom , PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.NSIS , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.PyInstaller , PyXMake.Build.Make.Sphinx , PyXMake.Build.Make.SSH
- Message : PyXMake.Tools.ErrorHandling.TransitionError
- msvsc : PyXMake.Build.Make.Make

### - n -

- no_append_arch : PyXMake.Build.Make.Py2X
- no_static_mkl : PyXMake.Build.Make.Py2X

### - o -

- outdir : PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Make
- outlibs : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH
- outmodule : PyXMake.Build.Make.Fortran , PyXMake.Build.Make.SSH

### - p -

- path2exe : PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.NSIS , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.Sphinx , PyXMake.Build.Make.SSH
- postcmd : PyXMake.Build.Make.Make , PyXMake.Build.Make.SSH
- precmd : PyXMake.Build.Make.Custom , PyXMake.Build.Make.Make , PyXMake.Build.Make.PyInstaller
- Previous : PyXMake.Tools.ErrorHandling.TransitionError

### - s -

- scrtdir : PyXMake.Build.Make.Make
- setarch : PyXMake.Build.Make.Make
- srcdir : PyXMake.Build.Make.Make
- srcs : PyXMake.Build.Make.Make
- ssh_client : PyXMake.Build.Make.SSH
- stype : PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Make

### - t -

- temps : PyXMake.Build.Make.CCxx , PyXMake.Build.Make.Doxygen , PyXMake.Build.Make.Fortran , PyXMake.Build.Make.Make , PyXMake.Build.Make.Py2X , PyXMake.Build.Make.SSH

### - v -

- verbose : PyXMake.Build.Make.Make

### - w -

- workspace : PyXMake.Build.Make.SSH